@@ -4,5 +4,5 @@ from dt_duckiematrix_protocols import CBorMessage
 
 
 @dataclasses.dataclass
-class CameraFrame(CBorMessage):
+class EmptyMessage(CBorMessage):
     __empty__: str = ""
